@@ -17,11 +17,11 @@ OpenServices::SNMP::Plugin::Updates - Expose pending security updates over SNMP
 
 =head1 VERSION
 
-Version 1.0.1
+Version 1.0.2
 
 =cut
 
-our $VERSION = '1.0.1';
+our $VERSION = '1.0.2';
 
 =head1 BASE OID
 
@@ -80,7 +80,7 @@ sub check {
             my $output = qx/apt-get upgrade -s/;
             my @packages;
             foreach my $line (split /\n/, $output) {
-                if (my ($name, $version) = $line =~ /^Inst (\S+) \[(\S+)\] \(\S+ Debian:security \[\S+\]\)/) {
+                if (my ($name, $version) = $line =~ /^Inst (\S+) \[\S+\] \((\S+) (?:Debian:security|Debian-Security:\d+\/\w+) \[\S+\]\)/) {
                     push @packages, "$name-$version";
                 }
             }
@@ -96,7 +96,7 @@ sub check {
             my $output = qx/yum list-security -y/;
             my @packages;
             foreach my $line (split /\n/, $output) {
-                if (my ($name) = $line =~ /^\w+-\d+[:-]\d+ +\S+ +(\S+)$/) {
+                if (my ($name) = $line =~ /^\w+-\d+[:-]\d+ \S+ (\S+)$/) {
                     push @packages, $name;
                 }
             }
